@@ -85,6 +85,10 @@ BPSRATES = (9600, 19200, 38400, 57600, 115200, 230400, 460800, 921600, 4800)
 NMEA_PROTOCOL = 0
 UBX_PROTOCOL = 1
 MIXED_PROTOCOL = 2
+# display formats
+PARSED = 0
+BIN = 1
+HEX = 2
 # connection type flags:
 DISCONNECTED = 0
 CONNECTED = 1
